@@ -15,9 +15,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-"""Framework-agnostic optimizer tools, both generic or FL-specific. In more
-details, we here define an `Optimizer` class that wraps together a set of 
-modules, used to implement various optimization and regularization techniques.
+"""Framework-agnostic optimizer tools, both generic or FL-specific.
+
+In more details, we here define an `Optimizer` class that wraps together a set
+of plug-in modules, used to implement various optimization and regularization
+techniques.
 
 Main class:
 * Optimizer: Base class to define gradient-descent-based optimizers.
